# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: messaging/v1/messaging.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'messaging/v1/messaging.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cmessaging/v1/messaging.proto\x12\x15mellions.messaging.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x95\x13\n\x0bJobDispatch\x12?\n\x0f\x65tl_job_context\x18\x01 \x01(\x0b\x32$.mellions.messaging.v1.ETLJobContextH\x00\x12M\n\x16\x65tl_completion_context\x18\x03 \x01(\x0b\x32+.mellions.messaging.v1.ETLCompletionContextH\x00\x12U\n\x1aposting_completion_context\x18\x04 \x01(\x0b\x32/.mellions.messaging.v1.PostingCompletionContextH\x00\x12l\n&category_determination_request_context\x18\x06 \x01(\x0b\x32:.mellions.messaging.v1.CategoryDeterminationRequestContextH\x00\x12n\n\'category_determination_response_context\x18\x07 \x01(\x0b\x32;.mellions.messaging.v1.CategoryDeterminationResponseContextH\x00\x12\x45\n\x12\x63oa_update_context\x18\t \x01(\x0b\x32\'.mellions.messaging.v1.COAUpdateContextH\x00\x12O\n\x17webhook_ingress_context\x18\n \x01(\x0b\x32,.mellions.messaging.v1.WebhookIngressContextH\x00\x12s\n*posting_rule_determination_request_context\x18\x0b \x01(\x0b\x32=.mellions.messaging.v1.PostingRuleDeterminationRequestContextH\x00\x12K\n\x15generic_event_context\x18\x0c \x01(\x0b\x32*.mellions.messaging.v1.GenericEventContextH\x00\x12\x45\n\x12goal_event_context\x18\r \x01(\x0b\x32\'.mellions.messaging.v1.GoalEventContextH\x00\x12\x45\n\x12\x64\x61ta_ready_context\x18\x0e \x01(\x0b\x32\'.mellions.messaging.v1.DataReadyContextH\x00\x12M\n\x16goal_operation_request\x18\x0f \x01(\x0b\x32+.mellions.messaging.v1.GoalOperationRequestH\x00\x12O\n\x17goal_operation_response\x18\x10 \x01(\x0b\x32,.mellions.messaging.v1.GoalOperationResponseH\x00\x12I\n\x14goal_subledger_event\x18\x11 \x01(\x0b\x32).mellions.messaging.v1.GoalSubledgerEventH\x00\x12\x42\n\x10suggestion_event\x18\x12 \x01(\x0b\x32&.mellions.messaging.v1.SuggestionEventH\x00\x12u\n+posting_rule_determination_response_context\x18\x13 \x01(\x0b\x32>.mellions.messaging.v1.PostingRuleDeterminationResponseContextH\x00\x12M\n\x16\x64\x61ta_available_context\x18\x14 \x01(\x0b\x32+.mellions.messaging.v1.DataAvailableContextH\x00\x12O\n\x17insight_trigger_context\x18\x16 \x01(\x0b\x32,.mellions.messaging.v1.InsightTriggerContextH\x00\x12Q\n\x18\x62\x61\x63kfill_trigger_context\x18\x17 \x01(\x0b\x32-.mellions.messaging.v1.BackfillTriggerContextH\x00\x12\x45\n\x12\x65tl_failed_context\x18\x1b \x01(\x0b\x32\'.mellions.messaging.v1.ETLFailedContextH\x00\x12M\n\x16posting_failed_context\x18\x1c \x01(\x0b\x32+.mellions.messaging.v1.PostingFailedContextH\x00\x12O\n\x18\x66_x_rate_request_context\x18\x1d \x01(\x0b\x32+.mellions.messaging.v1.FXRateRequestContextH\x00\x12Q\n\x19\x66_x_rate_response_context\x18\x1e \x01(\x0b\x32,.mellions.messaging.v1.FXRateResponseContextH\x00\x12`\n insight_analysis_request_context\x18! \x01(\x0b\x32\x34.mellions.messaging.v1.InsightAnalysisRequestContextH\x00\x12\x62\n!insight_analysis_response_context\x18\" \x01(\x0b\x32\x35.mellions.messaging.v1.InsightAnalysisResponseContextH\x00\x12Q\n\x18taxonomy_release_context\x18# \x01(\x0b\x32-.mellions.messaging.v1.TaxonomyReleaseContextH\x00\x12Z\n\x1dposting_rules_release_context\x18$ \x01(\x0b\x32\x31.mellions.messaging.v1.PostingRulesReleaseContextH\x00\x12[\n\x1d\x63onnection_reconciled_context\x18% \x01(\x0b\x32\x32.mellions.messaging.v1.ConnectionReconciledContextH\x00\x42\n\n\x08job_typeJ\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06J\x04\x08\x08\x10\tJ\x04\x08\x15\x10\x16J\x04\x08\x18\x10\x19J\x04\x08\x1a\x10\x1bJ\x04\x08\x1f\x10 \"\xe2\x01\n\rETLJobContext\x12\x32\n\tsync_type\x18\x02 \x01(\x0e\x32\x1f.mellions.messaging.v1.SyncType\x12.\n\nstart_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12\x30\n\x04\x64\x61ta\x18\x06 \x03(\x0b\x32\".mellions.messaging.v1.DataDetails\"\xb4\x01\n\x14\x45TLCompletionContext\x12\x44\n\x12processing_summary\x18\x02 \x01(\x0b\x32(.mellions.messaging.v1.ProcessingSummary\x12\x42\n\x0fquality_metrics\x18\x03 \x01(\x0b\x32).mellions.messaging.v1.DataQualityMetrics\x12\x12\n\nnext_steps\x18\x04 \x03(\t\"\xc5\x01\n\x18PostingCompletionContext\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12>\n\x0fposting_summary\x18\x03 \x01(\x0b\x32%.mellions.messaging.v1.PostingSummary\x12\x17\n\x0fjournal_entries\x18\x04 \x03(\t\x12\x19\n\x11\x61i_required_items\x18\x05 \x03(\t\x12\x12\n\nnext_steps\x18\x06 \x03(\t\x12\x11\n\tfinalized\x18\x07 \x01(\x08\"\xdc\x03\n\x16\x42\x61\x63kfillTriggerContext\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x33\n\ndata_types\x18\x04 \x03(\x0e\x32\x1f.mellions.messaging.v1.DataType\x12\x30\n\x0ctriggered_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0etrigger_source\x18\x06 \x01(\t\x12\x33\n\nstart_date\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x31\n\x08\x65nd_date\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12\x16\n\x0e\x63orrelation_id\x18\t \x01(\t\x12M\n\x08metadata\x18\n \x03(\x0b\x32;.mellions.messaging.v1.BackfillTriggerContext.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0b_start_dateB\x0b\n\t_end_date\"\xaf\x02\n\x15WebhookIngressContext\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x12\n\nevent_type\x18\x03 \x01(\t\x12\x15\n\rconnection_id\x18\x04 \x01(\t\x12\x13\n\x0braw_payload\x18\x05 \x01(\x0c\x12\x17\n\x0fidempotency_key\x18\x06 \x01(\t\x12/\n\x0breceived_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\x07headers\x18\x08 \x03(\x0b\x32\x39.mellions.messaging.v1.WebhookIngressContext.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x02\n\x14GoalOperationRequest\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x0f\n\x07goal_id\x18\x03 \x01(\t\x12\x17\n\x0fidempotency_key\x18\x04 \x01(\t\x12\x38\n\x07\x65\x61rmark\x18\n \x01(\x0b\x32%.mellions.messaging.v1.EarmarkRequestH\x00\x12\x34\n\x05spend\x18\x0b \x01(\x0b\x32#.mellions.messaging.v1.SpendRequestH\x00\x12:\n\x08\x61llocate\x18\x0c \x01(\x0b\x32&.mellions.messaging.v1.AllocateRequestH\x00\x12\x36\n\x06refund\x18\r \x01(\x0b\x32$.mellions.messaging.v1.RefundRequestH\x00\x42\x0b\n\toperation\"\xf7\x02\n\x15GoalOperationResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x12\n\nerror_code\x18\x03 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12\x16\n\x0e\x63orrelation_id\x18\x05 \x01(\t\x12\x36\n\x07\x65ntries\x18\n \x03(\x0b\x32%.mellions.messaging.v1.SubledgerEntry\x12^\n\x12\x61ggregates_by_goal\x18\x0b \x03(\x0b\x32\x42.mellions.messaging.v1.GoalOperationResponse.AggregatesByGoalEntry\x1a^\n\x15\x41ggregatesByGoalEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.mellions.messaging.v1.GoalAggregates:\x02\x38\x01\"\xd3\x01\n\x12GoalSubledgerEvent\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x0f\n\x07goal_id\x18\x03 \x01(\t\x12\x11\n\toperation\x18\x04 \x01(\t\x12\x34\n\x05\x65ntry\x18\x05 \x01(\x0b\x32%.mellions.messaging.v1.SubledgerEntry\x12\x39\n\naggregates\x18\x06 \x01(\x0b\x32%.mellions.messaging.v1.GoalAggregates\x12\x16\n\x0e\x63orrelation_id\x18\x07 \x01(\t\"\xaf\x02\n\x15InsightTriggerContext\x12\x14\n\x0cperiod_month\x18\x02 \x01(\t\x12\x18\n\x10max_entry_cursor\x18\x03 \x01(\t\x12\x10\n\x08\x62\x61tch_id\x18\x04 \x01(\t\x12\x15\n\rentries_count\x18\x05 \x01(\x05\x12/\n\x0boccurred_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63orrelation_id\x18\x07 \x01(\t\x12\x46\n\x05hints\x18\x08 \x03(\x0b\x32\x37.mellions.messaging.v1.InsightTriggerContext.HintsEntry\x1a,\n\nHintsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe2\x01\n\x10\x44\x61taReadyContext\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x1e\n\x16latest_posting_version\x18\x03 \x01(\t\x12\x1a\n\x12ledger_snapshot_id\x18\x04 \x01(\t\x12\x1b\n\x13transactions_posted\x18\x05 \x01(\x05\x12\x1a\n\x12transactions_total\x18\x06 \x01(\x05\x12\x1b\n\x13unreviewed_ai_count\x18\x07 \x01(\x05\x12\x19\n\x11\x61i_required_items\x18\x08 \x03(\t\x12\x11\n\tfinalized\x18\t \x01(\x08\"L\n#CategoryDeterminationRequestContext\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x11\n\ttxn_count\x18\x03 \x01(\x05\"\xbd\x01\n$CategoryDeterminationResponseContext\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x37\n\x06status\x18\x03 \x01(\x0e\x32\'.mellions.messaging.v1.ProcessingStatus\x12\x16\n\x0e\x65nriched_count\x18\x04 \x01(\x05\x12\x14\n\x0c\x66\x61iled_count\x18\x05 \x01(\x05\x12\x1a\n\x12processing_time_ms\x18\x06 \x01(\x03\"\x95\x01\n&PostingRuleDeterminationRequestContext\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x11\n\ttxn_count\x18\x03 \x01(\x05\x12\x44\n\x12\x64\x65termination_type\x18\x04 \x01(\x0e\x32(.mellions.messaging.v1.DeterminationType\"\xc0\x01\n\'PostingRuleDeterminationResponseContext\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x37\n\x06status\x18\x03 \x01(\x0e\x32\'.mellions.messaging.v1.ProcessingStatus\x12\x16\n\x0eresolved_count\x18\x04 \x01(\x05\x12\x14\n\x0c\x66\x61iled_count\x18\x05 \x01(\x05\x12\x1a\n\x12processing_time_ms\x18\x06 \x01(\x03\"\xcf\x01\n\x1dInsightAnalysisRequestContext\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x38\n\x0cinsight_type\x18\x03 \x01(\x0e\x32\".mellions.messaging.v1.InsightType\x12\x30\n\x0cperiod_start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nperiod_end\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc3\x01\n\x1eInsightAnalysisResponseContext\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x37\n\x06status\x18\x03 \x01(\x0e\x32\'.mellions.messaging.v1.ProcessingStatus\x12\x38\n\x0cinsight_type\x18\x04 \x01(\x0e\x32\".mellions.messaging.v1.InsightType\x12\x1a\n\x12processing_time_ms\x18\x05 \x01(\x03\"\x83\x02\n\x16TaxonomyReleaseContext\x12\x12\n\nrelease_id\x18\x02 \x01(\t\x12:\n\rtaxonomy_type\x18\x03 \x01(\x0e\x32#.mellions.messaging.v1.TaxonomyType\x12\x0f\n\x07version\x18\x04 \x01(\x05\x12\x15\n\rsha256_digest\x18\x05 \x01(\t\x12\x30\n\x0crelease_date\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x0erelease_status\x18\x06 \x01(\x0e\x32\'.mellions.messaging.v1.COAReleaseStatus\"\xdf\x01\n\x1aPostingRulesReleaseContext\x12\x12\n\nrelease_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x15\n\rsha256_digest\x18\x04 \x01(\t\x12\x12\n\nrule_count\x18\x05 \x01(\x05\x12\x30\n\x0crelease_date\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x0erelease_status\x18\x06 \x01(\x0e\x32\'.mellions.messaging.v1.COAReleaseStatus\"\xd5\x01\n\x10\x43OAUpdateContext\x12\x17\n\x0frelease_version\x18\x02 \x01(\t\x12\x30\n\x0crelease_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x0erelease_status\x18\x04 \x01(\x0e\x32\'.mellions.messaging.v1.COAReleaseStatus\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\'.mellions.messaging.v1.COAApplicability\"\xad\x02\n\x13GenericEventContext\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12N\n\nattributes\x18\x04 \x03(\x0b\x32:.mellions.messaging.v1.GenericEventContext.AttributesEntry\x12\x13\n\x0braw_payload\x18\x05 \x01(\x0c\x12\x14\n\x0c\x63ontent_type\x18\x06 \x01(\t\x12\x17\n\x0fidempotency_key\x18\x07 \x01(\t\x12/\n\x0boccurred_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdd\x01\n\x10GoalEventContext\x12\x0f\n\x07goal_id\x18\x02 \x01(\t\x12@\n\x0eoperation_type\x18\x03 \x01(\x0e\x32(.mellions.messaging.v1.GoalOperationType\x12\x38\n\x07payload\x18\x04 \x01(\x0b\x32\'.mellions.messaging.v1.GoalEventPayload\x12<\n\nallocation\x18\x05 \x01(\x0b\x32(.mellions.messaging.v1.AllocationContext\"\xc0\x02\n\x0fSuggestionEvent\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x16\n\x0etransaction_id\x18\x03 \x01(\t\x12\x15\n\rsuggestion_id\x18\x04 \x01(\t\x12\x12\n\nconfidence\x18\x05 \x01(\x01\x12>\n\ncandidates\x18\x06 \x03(\x0b\x32*.mellions.messaging.v1.SuggestionCandidate\x12\x37\n\x06status\x18\x07 \x01(\x0e\x32\'.mellions.messaging.v1.SuggestionStatus\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bresolved_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x88\x02\n\x14\x44\x61taAvailableContext\x12\x10\n\x08\x62\x61tch_id\x18\x02 \x01(\t\x12\x12\n\nitem_count\x18\x03 \x01(\x05\x12\x36\n\x0b\x64\x61ta_status\x18\x04 \x01(\x0e\x32!.mellions.messaging.v1.DataStatus\x12:\n\rposting_state\x18\x05 \x01(\x0e\x32#.mellions.messaging.v1.PostingState\x12\x16\n\x0e\x66\x61ilure_reason\x18\x06 \x01(\t\x12\x14\n\x0cposted_count\x18\x07 \x01(\x05\x12\x14\n\x0c\x66\x61iled_count\x18\x08 \x01(\x05\x12\x12\n\nfailed_ids\x18\t \x03(\t\"\xc9\x01\n\x10\x45TLFailedContext\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x12\n\nerror_code\x18\x03 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12\x17\n\x0f\x66\x61iled_at_stage\x18\x05 \x01(\t\x12\x19\n\x11records_processed\x18\x06 \x01(\x05\x12\x16\n\x0erecords_failed\x18\x07 \x01(\x05\x12\x11\n\tretriable\x18\x08 \x01(\x08\x12\x1b\n\x13original_message_id\x18\t \x01(\t\"\xb8\x01\n\x14PostingFailedContext\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x12\n\nerror_code\x18\x03 \x01(\t\x12\x15\n\rerror_message\x18\x04 \x01(\t\x12\x1e\n\x16\x66\x61iled_transaction_ids\x18\x05 \x03(\t\x12\x15\n\rsuccess_count\x18\x06 \x01(\x05\x12\x11\n\tretriable\x18\x07 \x01(\x08\x12\x1b\n\x13original_message_id\x18\x08 \x01(\t\"\xb0\x02\n\x14\x46XRateRequestContext\x12>\n\x0crequest_type\x18\x02 \x01(\x0e\x32(.mellions.messaging.v1.FXRateRequestType\x12\x16\n\x0e\x63urrency_codes\x18\x03 \x03(\t\x12\x15\n\rbase_currency\x18\x04 \x01(\t\x12.\n\nas_of_date\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstart_date\x18\x33 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\x34 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13is_fetch_if_missing\x18\t \x01(\x08\"\xd1\x01\n\x15\x46XRateResponseContext\x12\x15\n\rbase_currency\x18\x02 \x01(\t\x12\x31\n\x05rates\x18\x03 \x03(\x0b\x32\".mellions.messaging.v1.FXRateEntry\x12;\n\x06status\x18\x05 \x01(\x0e\x32+.mellions.messaging.v1.FXRateResponseStatus\x12\x15\n\rerror_message\x18\x06 \x01(\t\x12\x1a\n\x12missing_currencies\x18\x07 \x03(\t\"\xfe\x01\n\x1b\x43onnectionReconciledContext\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12!\n\x19merged_into_connection_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\tentity_id\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12G\n\x12\x64uplicate_accounts\x18\x06 \x03(\x0b\x32+.mellions.messaging.v1.DuplicateAccountPair\x12\x12\n\nmatch_tier\x18\x07 \x01(\t\x12\x12\n\nmatch_hash\x18\x08 \x01(\t\"L\n\x14\x44uplicateAccountPair\x12\x19\n\x11source_account_id\x18\x01 \x01(\t\x12\x19\n\x11target_account_id\x18\x02 \x01(\t\"\xa2\x02\n\x0fIdentityContext\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tentity_id\x18\x02 \x01(\t\x12\x0f\n\x07item_id\x18\x03 \x01(\t\x12\x10\n\x08\x62\x61tch_id\x18\x04 \x01(\t\x12\x32\n\tdata_type\x18\x05 \x01(\x0e\x32\x1f.mellions.messaging.v1.DataType\x12\x0e\n\x06job_id\x18\n \x01(\t\x12\x12\n\nrequest_id\x18\x0b \x01(\t\x12\x10\n\x08\x65vent_id\x18\x0c \x01(\t\x12\x15\n\rconnection_id\x18\x14 \x01(\t\x12\x10\n\x08provider\x18\x15 \x01(\t\x12\x16\n\x0etrigger_source\x18\x16 \x01(\t\x12\x17\n\x0fidempotency_key\x18\x1e \x01(\tJ\x04\x08\x06\x10\x07\"\xdb\x02\n\rMessageHeader\x12\x12\n\nmessage_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63orrelation_id\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x03\x12<\n\x0esource_service\x18\x04 \x01(\x0e\x32$.mellions.messaging.v1.SourceService\x12<\n\x0etarget_service\x18\x05 \x01(\x0e\x32$.mellions.messaging.v1.TargetService\x12\x38\n\x0cmessage_type\x18\x06 \x01(\x0e\x32\".mellions.messaging.v1.MessageType\x12\x0f\n\x07version\x18\x07 \x01(\t\x12\x38\n\x08identity\x18\n \x01(\x0b\x32&.mellions.messaging.v1.IdentityContextJ\x04\x08\x08\x10\tJ\x04\x08\t\x10\n\"\xe2\x01\n\x11ProcessingSummary\x12\x19\n\x11records_processed\x18\x01 \x01(\x05\x12\x16\n\x0erecords_failed\x18\x02 \x01(\x05\x12\x17\n\x0frecords_skipped\x18\x03 \x01(\x05\x12\x1a\n\x12processing_time_ms\x18\x04 \x01(\x03\x12\x37\n\x06status\x18\x05 \x01(\x0e\x32\'.mellions.messaging.v1.ProcessingStatus\x12\x15\n\rquality_score\x18\x06 \x01(\x01\x12\x15\n\rerror_summary\x18\x07 \x03(\t\"\xad\x03\n\x12\x44\x61taQualityMetrics\x12\x15\n\roverall_score\x18\x01 \x01(\x01\x12\\\n\x12\x66ield_completeness\x18\x02 \x03(\x0b\x32@.mellions.messaging.v1.DataQualityMetrics.FieldCompletenessEntry\x12\\\n\x12validation_results\x18\x03 \x03(\x0b\x32@.mellions.messaging.v1.DataQualityMetrics.ValidationResultsEntry\x12\x19\n\x11\x63\x61tegory_accuracy\x18\x04 \x01(\x01\x12\x18\n\x10\x64uplication_rate\x18\x05 \x01(\x01\x12\x1b\n\x13\x65nrichment_coverage\x18\x06 \x01(\x01\x1a\x38\n\x16\x46ieldCompletenessEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a\x38\n\x16ValidationResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x9a\x02\n\x0ePostingSummary\x12\x1a\n\x12transactions_total\x18\x01 \x01(\x05\x12\x1b\n\x13transactions_posted\x18\x02 \x01(\x05\x12\x1b\n\x13transactions_failed\x18\x03 \x01(\x05\x12 \n\x18transactions_ai_required\x18\x04 \x01(\x05\x12\x1f\n\x17journal_entries_created\x18\x05 \x01(\x05\x12\x1a\n\x12processing_time_ms\x18\x06 \x01(\x03\x12\x37\n\x06status\x18\x07 \x01(\x0e\x32\'.mellions.messaging.v1.ProcessingStatus\x12\x1a\n\x12\x62\x61lance_validation\x18\x08 \x01(\x08\"3\n\x0b\x44\x61taDetails\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61ta_ids\x18\x02 \x03(\t\"\x93\x01\n\nPostingLeg\x12\x14\n\x0c\x61\x63\x63ount_code\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\t\x12\x34\n\nentry_side\x18\x03 \x01(\x0e\x32 .mellions.messaging.v1.EntrySide\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"\xb8\x03\n\x10GoalEventPayload\x12\r\n\x05title\x18\x01 \x01(\t\x12\x14\n\x0c\x63\x61tegory_key\x18\x02 \x01(\t\x12\x15\n\rtarget_amount\x18\x03 \x01(\x01\x12\x17\n\x0f\x63urrent_balance\x18\x04 \x01(\x01\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12.\n\nstart_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0btarget_date\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x06status\x18\x08 \x01(\x0e\x32!.mellions.messaging.v1.GoalStatus\x12\x10\n\x08priority\x18\t \x01(\x05\x12;\n\x0bperformance\x18\n \x01(\x0e\x32&.mellions.messaging.v1.GoalPerformance\x12\x46\n\x13\x61llocation_settings\x18\x0b \x01(\x0b\x32).mellions.messaging.v1.AllocationSettings\x12\x12\n\naccount_id\x18\x0c \x01(\t\"\xaf\x02\n\x12\x41llocationSettings\x12>\n\x0f\x61llocation_type\x18\x01 \x01(\x0e\x32%.mellions.messaging.v1.AllocationType\x12\x19\n\x11\x61llocation_amount\x18\x02 \x01(\x01\x12\x1d\n\x15\x61llocation_percentage\x18\x03 \x01(\x01\x12=\n\tfrequency\x18\x04 \x01(\x0e\x32*.mellions.messaging.v1.AllocationFrequency\x12\x16\n\x0e\x61llocation_day\x18\x05 \x01(\x05\x12\x11\n\tis_active\x18\x06 \x01(\x08\x12\x35\n\x11next_trigger_date\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x81\x02\n\x11\x41llocationContext\x12\x15\n\rallocation_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x19\n\x11source_account_id\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x65stination_account_id\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x61ilure_reason\x18\x06 \x01(\t\x12\x30\n\x0ctriggered_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd3\x01\n\x0e\x45\x61rmarkRequest\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x01\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12\x14\n\x0cposting_date\x18\x03 \x01(\t\x12R\n\x0fsource_metadata\x18\x04 \x03(\x0b\x32\x39.mellions.messaging.v1.EarmarkRequest.SourceMetadataEntry\x1a\x35\n\x13SourceMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x0cSpendRequest\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x01\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12\x16\n\x0etransaction_id\x18\x03 \x01(\t\x12\x14\n\x0cposting_date\x18\x04 \x01(\t\x12\x0c\n\x04note\x18\x05 \x01(\t\"\x89\x01\n\x0f\x41llocateRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\t\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12\x14\n\x0cposting_date\x18\x03 \x01(\t\x12\x36\n\x0b\x61llocations\x18\x04 \x03(\x0b\x32!.mellions.messaging.v1.Allocation\";\n\nAllocation\x12\x0f\n\x07goal_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0c\n\x04note\x18\x03 \x01(\t\"\x88\x01\n\rRefundRequest\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x01\x12\x10\n\x08\x63urrency\x18\x02 \x01(\t\x12\x19\n\x11original_entry_id\x18\x03 \x01(\t\x12\x16\n\x0etransaction_id\x18\x04 \x01(\t\x12\x14\n\x0cposting_date\x18\x05 \x01(\t\x12\x0c\n\x04note\x18\x06 \x01(\t\"\x9d\x02\n\x0eSubledgerEntry\x12\x10\n\x08\x65ntry_id\x18\x01 \x01(\t\x12\x0f\n\x07goal_id\x18\x02 \x01(\t\x12\x38\n\nentry_type\x18\x03 \x01(\x0e\x32$.mellions.messaging.v1.GoalEntryType\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x01\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x14\n\x0cposting_date\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0etransaction_id\x18\x08 \x01(\t\x12\x13\n\x0bis_reversed\x18\t \x01(\x08\x12\x19\n\x11original_entry_id\x18\n \x01(\t\"\xdd\x01\n\x0eGoalAggregates\x12\x17\n\x0ftotal_allocated\x18\x01 \x01(\x01\x12\x13\n\x0btotal_spent\x18\x02 \x01(\x01\x12\x16\n\x0etotal_refunded\x18\x03 \x01(\x01\x12\x11\n\tnet_spent\x18\x04 \x01(\x01\x12\x11\n\tremaining\x18\x05 \x01(\x01\x12\x18\n\x10\x66unding_progress\x18\x06 \x01(\x01\x12\x1c\n\x14\x63onsumption_progress\x18\x07 \x01(\x01\x12\x15\n\rtarget_amount\x18\x08 \x01(\x01\x12\x10\n\x08\x63urrency\x18\t \x01(\t\"o\n\x13SuggestionCandidate\x12\x0f\n\x07goal_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x10\n\x08\x63urrency\x18\x03 \x01(\t\x12\x12\n\nconfidence\x18\x04 \x01(\x01\x12\x11\n\trationale\x18\x05 \x01(\t\"\x98\x01\n\x0b\x46XRateEntry\x12\x15\n\rcurrency_code\x18\x01 \x01(\t\x12\x0c\n\x04rate\x18\x02 \x01(\t\x12\x32\n\x0e\x65\x66\x66\x65\x63tive_date\x18\x32 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06source\x18\x04 \x01(\t\x12 \n\x18is_fetched_from_provider\x18\x05 \x01(\x08*\x96\x02\n\x10ProcessingStatus\x12!\n\x1dPROCESSING_STATUS_UNSPECIFIED\x10\x00\x12\x1d\n\x19PROCESSING_STATUS_PENDING\x10\x01\x12 \n\x1cPROCESSING_STATUS_PROCESSING\x10\x02\x12\x1d\n\x19PROCESSING_STATUS_SUCCESS\x10\x03\x12\x1c\n\x18PROCESSING_STATUS_FAILED\x10\x04\x12\x1b\n\x17PROCESSING_STATUS_RETRY\x10\x05\x12\x1d\n\x19PROCESSING_STATUS_TIMEOUT\x10\x06\x12%\n!PROCESSING_STATUS_PARTIAL_SUCCESS\x10\x07*\x90\x03\n\x08\x44\x61taType\x12\x19\n\x15\x44\x41TA_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x44\x41TA_TYPE_TRANSACTIONS\x10\x01\x12\x16\n\x12\x44\x41TA_TYPE_ACCOUNTS\x10\x02\x12\x19\n\x15\x44\x41TA_TYPE_LIABILITIES\x10\x03\x12\x19\n\x15\x44\x41TA_TYPE_INVESTMENTS\x10\x04\x12\x16\n\x12\x44\x41TA_TYPE_IDENTITY\x10\x05\x12\x14\n\x10\x44\x41TA_TYPE_ASSETS\x10\x06\x12\x14\n\x10\x44\x41TA_TYPE_INCOME\x10\x07\x12\x1c\n\x18\x44\x41TA_TYPE_CREDIT_DETAILS\x10\x08\x12\x19\n\x15\x44\x41TA_TYPE_CONNECTIONS\x10\t\x12\x18\n\x14\x44\x41TA_TYPE_STATEMENTS\x10\n\x12\x13\n\x0f\x44\x41TA_TYPE_GOALS\x10\x0b\x12\x1f\n\x1b\x44\x41TA_TYPE_DASHBOARD_WIDGETS\x10\x0c\x12\x19\n\x15\x44\x41TA_TYPE_INSTITUTION\x10\r\x12\x17\n\x13\x44\x41TA_TYPE_RECURRING\x10\x0e*\x96\x06\n\rSourceService\x12\x1e\n\x1aSOURCE_SERVICE_UNSPECIFIED\x10\x00\x12\x1b\n\x17SOURCE_SERVICE_NEONLINK\x10\x01\x12\x1e\n\x1aSOURCE_SERVICE_DATASERVICE\x10\x02\x12\"\n\x1eSOURCE_SERVICE_POSTING_SERVICE\x10\x03\x12 \n\x1cSOURCE_SERVICE_FINAI_SERVICE\x10\x04\x12\x1f\n\x1bSOURCE_SERVICE_SYNC_SERVICE\x10\x05\x12\"\n\x1eSOURCE_SERVICE_WEBHOOK_SERVICE\x10\x06\x12\x1f\n\x1bSOURCE_SERVICE_GOAL_SERVICE\x10\x07\x12\"\n\x1eSOURCE_SERVICE_FINAPIS_SERVICE\x10\x08\x12$\n SOURCE_SERVICE_DASHBOARD_SERVICE\x10\t\x12\x1c\n\x18SOURCE_SERVICE_CONNECTOR\x10\n\x12!\n\x1dSOURCE_SERVICE_FXRATE_SERVICE\x10\x0b\x12\x1c\n\x18SOURCE_SERVICE_MOBILEAPP\x10\x14\x12\x19\n\x15SOURCE_SERVICE_WEBAPP\x10\x15\x12\x18\n\x14SOURCE_SERVICE_PLAID\x10\x1e\x12\x19\n\x15SOURCE_SERVICE_STRIPE\x10\x1f\x12\x19\n\x15SOURCE_SERVICE_PAYPAL\x10 \x12\x1e\n\x1aSOURCE_SERVICE_MASTER_CARD\x10!\x12\x17\n\x13SOURCE_SERVICE_VISA\x10\"\x12\x1d\n\x19SOURCE_SERVICE_QUICKBOOKS\x10#\x12 \n\x1cSOURCE_SERVICE_MANUAL_UPLOAD\x10$\x12\x17\n\x13SOURCE_SERVICE_XERO\x10%\x12\x1b\n\x17SOURCE_SERVICE_BANK_API\x10&\x12\x1d\n\x19SOURCE_SERVICE_CSV_IMPORT\x10\'\x12\x19\n\x15SOURCE_SERVICE_FLINKS\x10(*\xad\x03\n\rTargetService\x12\x1e\n\x1aTARGET_SERVICE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTARGET_SERVICE_ETL_SERVICE\x10\x01\x12\"\n\x1eTARGET_SERVICE_POSTING_SERVICE\x10\x02\x12 \n\x1cTARGET_SERVICE_FINAI_SERVICE\x10\x03\x12\x1f\n\x1bTARGET_SERVICE_SYNC_SERVICE\x10\x04\x12\"\n\x1eTARGET_SERVICE_WEBHOOK_SERVICE\x10\x05\x12%\n!TARGET_SERVICE_MONITORING_SERVICE\x10\x06\x12\x1f\n\x1bTARGET_SERVICE_GOAL_SERVICE\x10\x07\x12\"\n\x1eTARGET_SERVICE_FINAPIS_SERVICE\x10\x08\x12$\n TARGET_SERVICE_DASHBOARD_SERVICE\x10\t\x12\x1c\n\x18TARGET_SERVICE_CONNECTOR\x10\n\x12!\n\x1dTARGET_SERVICE_FXRATE_SERVICE\x10\x0b*\xb0\x01\n\x08SyncType\x12\x19\n\x15SYNC_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15SYNC_TYPE_INCREMENTAL\x10\x01\x12\x12\n\x0eSYNC_TYPE_FULL\x10\x02\x12\x13\n\x0fSYNC_TYPE_DELTA\x10\x03\x12\x15\n\x11SYNC_TYPE_INITIAL\x10\x04\x12\x14\n\x10SYNC_TYPE_DELETE\x10\x05\x12\x18\n\x14SYNC_TYPE_HISTORICAL\x10\x06*T\n\tEntrySide\x12\x1a\n\x16\x45NTRY_SIDE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45NTRY_SIDE_DEBIT\x10\x01\x12\x15\n\x11\x45NTRY_SIDE_CREDIT\x10\x02*\xa3\x01\n\x11\x44\x65terminationType\x12\"\n\x1e\x44\x45TERMINATION_TYPE_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x44\x45TERMINATION_TYPE_INITIAL\x10\x01\x12\'\n#DETERMINATION_TYPE_RECLASSIFICATION\x10\x02\x12!\n\x1d\x44\x45TERMINATION_TYPE_CORRECTION\x10\x03*\xb9\x01\n\x0bInsightType\x12\x1c\n\x18INSIGHT_TYPE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aINSIGHT_TYPE_SAFE_TO_SPEND\x10\x01\x12\'\n#INSIGHT_TYPE_FINANCIAL_HEALTH_SCORE\x10\x02\x12\x1f\n\x1bINSIGHT_TYPE_SPENDING_TREND\x10\x03\x12\"\n\x1eINSIGHT_TYPE_ANOMALY_DETECTION\x10\x04*\x96\x01\n\x10\x43OAApplicability\x12!\n\x1d\x43OA_APPLICABILITY_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43OA_APPLICABILITY_PERSONAL\x10\x01\x12\x1e\n\x1a\x43OA_APPLICABILITY_BUSINESS\x10\x02\x12\x1f\n\x1b\x43OA_APPLICABILITY_UNIVERSAL\x10\x03*\x8d\x01\n\x10\x43OAReleaseStatus\x12\"\n\x1e\x43OA_RELEASE_STATUS_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43OA_RELEASE_STATUS_BETA\x10\x01\x12\x1b\n\x17\x43OA_RELEASE_STATUS_TEST\x10\x02\x12\x1b\n\x17\x43OA_RELEASE_STATUS_LIVE\x10\x03*{\n\x0cTaxonomyType\x12\x1d\n\x19TAXONOMY_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1eTAXONOMY_TYPE_BANKING_ACCOUNTS\x10\x01\x12(\n$TAXONOMY_TYPE_TRANSACTION_CATEGORIES\x10\x02*\xa5\x02\n\x11GoalOperationType\x12#\n\x1fGOAL_OPERATION_TYPE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aGOAL_OPERATION_TYPE_CREATE\x10\x01\x12\x1e\n\x1aGOAL_OPERATION_TYPE_UPDATE\x10\x02\x12\x1e\n\x1aGOAL_OPERATION_TYPE_DELETE\x10\x03\x12 \n\x1cGOAL_OPERATION_TYPE_COMPLETE\x10\x04\x12\x1d\n\x19GOAL_OPERATION_TYPE_PAUSE\x10\x05\x12\x1e\n\x1aGOAL_OPERATION_TYPE_RESUME\x10\x06\x12*\n&GOAL_OPERATION_TYPE_ALLOCATION_TRIGGER\x10\x07*\x8d\x01\n\nGoalStatus\x12\x1b\n\x17GOAL_STATUS_UNSPECIFIED\x10\x00\x12\x16\n\x12GOAL_STATUS_ACTIVE\x10\x01\x12\x16\n\x12GOAL_STATUS_PAUSED\x10\x02\x12\x19\n\x15GOAL_STATUS_COMPLETED\x10\x03\x12\x17\n\x13GOAL_STATUS_DELETED\x10\x04*\xa9\x01\n\x0fGoalPerformance\x12 \n\x1cGOAL_PERFORMANCE_UNSPECIFIED\x10\x00\x12\x1d\n\x19GOAL_PERFORMANCE_ON_TRACK\x10\x01\x12\x1a\n\x16GOAL_PERFORMANCE_AHEAD\x10\x02\x12\x1b\n\x17GOAL_PERFORMANCE_BEHIND\x10\x03\x12\x1c\n\x18GOAL_PERFORMANCE_AT_RISK\x10\x04*s\n\x0e\x41llocationType\x12\x1f\n\x1b\x41LLOCATION_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1c\x41LLOCATION_TYPE_FIXED_AMOUNT\x10\x01\x12\x1e\n\x1a\x41LLOCATION_TYPE_PERCENTAGE\x10\x02*\xe6\x01\n\x13\x41llocationFrequency\x12$\n ALLOCATION_FREQUENCY_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x41LLOCATION_FREQUENCY_WEEKLY\x10\x01\x12!\n\x1d\x41LLOCATION_FREQUENCY_BIWEEKLY\x10\x02\x12 \n\x1c\x41LLOCATION_FREQUENCY_MONTHLY\x10\x03\x12\"\n\x1e\x41LLOCATION_FREQUENCY_QUARTERLY\x10\x04\x12\x1f\n\x1b\x41LLOCATION_FREQUENCY_CUSTOM\x10\x05*\xc9\x01\n\rGoalEntryType\x12\x1f\n\x1bGOAL_ENTRY_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17GOAL_ENTRY_TYPE_EARMARK\x10\x01\x12\x1b\n\x17GOAL_ENTRY_TYPE_EXPENSE\x10\x02\x12\x1a\n\x16GOAL_ENTRY_TYPE_REFUND\x10\x03\x12$\n GOAL_ENTRY_TYPE_OPEN_BALANCE_ADJ\x10\x04\x12\x1b\n\x17GOAL_ENTRY_TYPE_REVERSE\x10\x05*\xb4\x01\n\x10SuggestionStatus\x12!\n\x1dSUGGESTION_STATUS_UNSPECIFIED\x10\x00\x12\x1d\n\x19SUGGESTION_STATUS_PENDING\x10\x01\x12\x1e\n\x1aSUGGESTION_STATUS_ACCEPTED\x10\x02\x12\x1f\n\x1bSUGGESTION_STATUS_DISMISSED\x10\x03\x12\x1d\n\x19SUGGESTION_STATUS_EXPIRED\x10\x04*\x8e\x01\n\nDataStatus\x12\x1b\n\x17\x44\x41TA_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15\x44\x41TA_STATUS_AVAILABLE\x10\x01\x12\x17\n\x13\x44\x41TA_STATUS_POSTING\x10\x02\x12\x16\n\x12\x44\x41TA_STATUS_POSTED\x10\x03\x12\x17\n\x13\x44\x41TA_STATUS_PARTIAL\x10\x04*\xb8\x01\n\x0cPostingState\x12\x1d\n\x19POSTING_STATE_UNSPECIFIED\x10\x00\x12\x19\n\x15POSTING_STATE_PENDING\x10\x01\x12\x1d\n\x19POSTING_STATE_IN_PROGRESS\x10\x02\x12\x1a\n\x16POSTING_STATE_COMPLETE\x10\x03\x12\x18\n\x14POSTING_STATE_FAILED\x10\x04\x12\x19\n\x15POSTING_STATE_PARTIAL\x10\x05*\xdb\x01\n\x11\x46XRateRequestType\x12$\n FX_RATE_REQUEST_TYPE_UNSPECIFIED\x10\x00\x12&\n\"FX_RATE_REQUEST_TYPE_FETCH_CURRENT\x10\x01\x12$\n FX_RATE_REQUEST_TYPE_FETCH_AS_OF\x10\x02\x12)\n%FX_RATE_REQUEST_TYPE_FETCH_HISTORICAL\x10\x03\x12\'\n#FX_RATE_REQUEST_TYPE_ADD_CURRENCIES\x10\x04*\xd3\x01\n\x14\x46XRateResponseStatus\x12\'\n#FX_RATE_RESPONSE_STATUS_UNSPECIFIED\x10\x00\x12#\n\x1f\x46X_RATE_RESPONSE_STATUS_SUCCESS\x10\x01\x12#\n\x1f\x46X_RATE_RESPONSE_STATUS_PARTIAL\x10\x02\x12!\n\x1d\x46X_RATE_RESPONSE_STATUS_ERROR\x10\x03\x12%\n!FX_RATE_RESPONSE_STATUS_NOT_FOUND\x10\x04*\xc5\r\n\x0bMessageType\x12\x1c\n\x18MESSAGE_TYPE_UNSPECIFIED\x10\x00\x12,\n(MESSAGE_TYPE_JOB_TRANSACTION_DATA_STAGED\x10\x01\x12)\n%MESSAGE_TYPE_JOB_ACCOUNTS_DATA_STAGED\x10\x02\x12,\n(MESSAGE_TYPE_JOB_LIABILITIES_DATA_STAGED\x10\x03\x12,\n(MESSAGE_TYPE_JOB_INVESTMENTS_DATA_STAGED\x10\x04\x12\x1f\n\x1bMESSAGE_TYPE_ETL_COMPLETION\x10\x07\x12\x1b\n\x17MESSAGE_TYPE_ETL_FAILED\x10\x08\x12\"\n\x1eMESSAGE_TYPE_POSTING_COMPLETED\x10\t\x12\x1f\n\x1bMESSAGE_TYPE_POSTING_FAILED\x10\n\x12\"\n\x1eMESSAGE_TYPE_PUSH_NOTIFICATION\x10\x0c\x12\x1b\n\x17MESSAGE_TYPE_COA_UPDATE\x10\x12\x12 \n\x1cMESSAGE_TYPE_WEBHOOK_INGRESS\x10\x19\x12\x1e\n\x1aMESSAGE_TYPE_GENERIC_EVENT\x10\x1a\x12\x1b\n\x17MESSAGE_TYPE_GOAL_EVENT\x10\x1b\x12\x1b\n\x17MESSAGE_TYPE_DATA_READY\x10\x1e\x12%\n!MESSAGE_TYPE_GOAL_EARMARK_REQUEST\x10\x1f\x12#\n\x1fMESSAGE_TYPE_GOAL_SPEND_REQUEST\x10 \x12&\n\"MESSAGE_TYPE_GOAL_ALLOCATE_REQUEST\x10!\x12$\n MESSAGE_TYPE_GOAL_REFUND_REQUEST\x10\"\x12&\n\"MESSAGE_TYPE_GOAL_EARMARK_RESPONSE\x10#\x12$\n MESSAGE_TYPE_GOAL_SPEND_RESPONSE\x10$\x12\'\n#MESSAGE_TYPE_GOAL_ALLOCATE_RESPONSE\x10%\x12%\n!MESSAGE_TYPE_GOAL_REFUND_RESPONSE\x10&\x12\'\n#MESSAGE_TYPE_GOAL_SUBLEDGER_WRITTEN\x10\'\x12(\n$MESSAGE_TYPE_GOAL_SUGGESTION_CREATED\x10(\x12)\n%MESSAGE_TYPE_GOAL_SUGGESTION_RESOLVED\x10)\x12%\n!MESSAGE_TYPE_INSIGHT_OLAP_TRIGGER\x10*\x12!\n\x1dMESSAGE_TYPE_BACKFILL_TRIGGER\x10+\x12\x1f\n\x1bMESSAGE_TYPE_DATA_AVAILABLE\x10,\x12(\n$MESSAGE_TYPE_JOB_RECURRING_TX_STAGED\x10/\x12\x1f\n\x1bMESSAGE_TYPE_FXRATE_REQUEST\x10\x30\x12 \n\x1cMESSAGE_TYPE_FXRATE_RESPONSE\x10\x31\x12/\n+MESSAGE_TYPE_CATEGORY_DETERMINATION_REQUEST\x10\x32\x12\x30\n,MESSAGE_TYPE_CATEGORY_DETERMINATION_RESPONSE\x10\x33\x12\x33\n/MESSAGE_TYPE_POSTING_RULE_DETERMINATION_REQUEST\x10\x34\x12\x34\n0MESSAGE_TYPE_POSTING_RULE_DETERMINATION_RESPONSE\x10\x35\x12)\n%MESSAGE_TYPE_INSIGHT_ANALYSIS_REQUEST\x10\x36\x12*\n&MESSAGE_TYPE_INSIGHT_ANALYSIS_RESPONSE\x10\x37\x12/\n+MESSAGE_TYPE_WEBHOOK_CONFIG_UPDATE_DETECTED\x10\x38\x12!\n\x1dMESSAGE_TYPE_TAXONOMY_RELEASE\x10\x39\x12&\n\"MESSAGE_TYPE_POSTING_RULES_RELEASE\x10:\x12&\n\"MESSAGE_TYPE_CONNECTION_RECONCILED\x10;\"\x04\x08\x05\x10\x05\"\x04\x08\x06\x10\x06\"\x04\x08\x0b\x10\x0b\"\x04\x08\r\x10\r\"\x04\x08\x13\x10\x13\"\x04\x08\x14\x10\x14\"\x04\x08\x15\x10\x15\"\x04\x08\x16\x10\x16\"\x04\x08\x18\x10\x18\"\x04\x08\x1c\x10\x1c\"\x04\x08\x1d\x10\x1d\"\x04\x08-\x10-\"\x04\x08.\x10.BDZBgithub.com/LetA-Tech/mcfo-neonlink/gen/go/messaging/v1;messagingv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'messaging.v1.messaging_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZBgithub.com/LetA-Tech/mcfo-neonlink/gen/go/messaging/v1;messagingv1'
  _globals['_BACKFILLTRIGGERCONTEXT_METADATAENTRY']._loaded_options = None
  _globals['_BACKFILLTRIGGERCONTEXT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_WEBHOOKINGRESSCONTEXT_HEADERSENTRY']._loaded_options = None
  _globals['_WEBHOOKINGRESSCONTEXT_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_GOALOPERATIONRESPONSE_AGGREGATESBYGOALENTRY']._loaded_options = None
  _globals['_GOALOPERATIONRESPONSE_AGGREGATESBYGOALENTRY']._serialized_options = b'8\001'
  _globals['_INSIGHTTRIGGERCONTEXT_HINTSENTRY']._loaded_options = None
  _globals['_INSIGHTTRIGGERCONTEXT_HINTSENTRY']._serialized_options = b'8\001'
  _globals['_GENERICEVENTCONTEXT_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_GENERICEVENTCONTEXT_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_DATAQUALITYMETRICS_FIELDCOMPLETENESSENTRY']._loaded_options = None
  _globals['_DATAQUALITYMETRICS_FIELDCOMPLETENESSENTRY']._serialized_options = b'8\001'
  _globals['_DATAQUALITYMETRICS_VALIDATIONRESULTSENTRY']._loaded_options = None
  _globals['_DATAQUALITYMETRICS_VALIDATIONRESULTSENTRY']._serialized_options = b'8\001'
  _globals['_EARMARKREQUEST_SOURCEMETADATAENTRY']._loaded_options = None
  _globals['_EARMARKREQUEST_SOURCEMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_PROCESSINGSTATUS']._serialized_start=13734
  _globals['_PROCESSINGSTATUS']._serialized_end=14012
  _globals['_DATATYPE']._serialized_start=14015
  _globals['_DATATYPE']._serialized_end=14415
  _globals['_SOURCESERVICE']._serialized_start=14418
  _globals['_SOURCESERVICE']._serialized_end=15208
  _globals['_TARGETSERVICE']._serialized_start=15211
  _globals['_TARGETSERVICE']._serialized_end=15640
  _globals['_SYNCTYPE']._serialized_start=15643
  _globals['_SYNCTYPE']._serialized_end=15819
  _globals['_ENTRYSIDE']._serialized_start=15821
  _globals['_ENTRYSIDE']._serialized_end=15905
  _globals['_DETERMINATIONTYPE']._serialized_start=15908
  _globals['_DETERMINATIONTYPE']._serialized_end=16071
  _globals['_INSIGHTTYPE']._serialized_start=16074
  _globals['_INSIGHTTYPE']._serialized_end=16259
  _globals['_COAAPPLICABILITY']._serialized_start=16262
  _globals['_COAAPPLICABILITY']._serialized_end=16412
  _globals['_COARELEASESTATUS']._serialized_start=16415
  _globals['_COARELEASESTATUS']._serialized_end=16556
  _globals['_TAXONOMYTYPE']._serialized_start=16558
  _globals['_TAXONOMYTYPE']._serialized_end=16681
  _globals['_GOALOPERATIONTYPE']._serialized_start=16684
  _globals['_GOALOPERATIONTYPE']._serialized_end=16977
  _globals['_GOALSTATUS']._serialized_start=16980
  _globals['_GOALSTATUS']._serialized_end=17121
  _globals['_GOALPERFORMANCE']._serialized_start=17124
  _globals['_GOALPERFORMANCE']._serialized_end=17293
  _globals['_ALLOCATIONTYPE']._serialized_start=17295
  _globals['_ALLOCATIONTYPE']._serialized_end=17410
  _globals['_ALLOCATIONFREQUENCY']._serialized_start=17413
  _globals['_ALLOCATIONFREQUENCY']._serialized_end=17643
  _globals['_GOALENTRYTYPE']._serialized_start=17646
  _globals['_GOALENTRYTYPE']._serialized_end=17847
  _globals['_SUGGESTIONSTATUS']._serialized_start=17850
  _globals['_SUGGESTIONSTATUS']._serialized_end=18030
  _globals['_DATASTATUS']._serialized_start=18033
  _globals['_DATASTATUS']._serialized_end=18175
  _globals['_POSTINGSTATE']._serialized_start=18178
  _globals['_POSTINGSTATE']._serialized_end=18362
  _globals['_FXRATEREQUESTTYPE']._serialized_start=18365
  _globals['_FXRATEREQUESTTYPE']._serialized_end=18584
  _globals['_FXRATERESPONSESTATUS']._serialized_start=18587
  _globals['_FXRATERESPONSESTATUS']._serialized_end=18798
  _globals['_MESSAGETYPE']._serialized_start=18801
  _globals['_MESSAGETYPE']._serialized_end=20534
  _globals['_JOBDISPATCH']._serialized_start=89
  _globals['_JOBDISPATCH']._serialized_end=2542
  _globals['_ETLJOBCONTEXT']._serialized_start=2545
  _globals['_ETLJOBCONTEXT']._serialized_end=2771
  _globals['_ETLCOMPLETIONCONTEXT']._serialized_start=2774
  _globals['_ETLCOMPLETIONCONTEXT']._serialized_end=2954
  _globals['_POSTINGCOMPLETIONCONTEXT']._serialized_start=2957
  _globals['_POSTINGCOMPLETIONCONTEXT']._serialized_end=3154
  _globals['_BACKFILLTRIGGERCONTEXT']._serialized_start=3157
  _globals['_BACKFILLTRIGGERCONTEXT']._serialized_end=3633
  _globals['_BACKFILLTRIGGERCONTEXT_METADATAENTRY']._serialized_start=3558
  _globals['_BACKFILLTRIGGERCONTEXT_METADATAENTRY']._serialized_end=3605
  _globals['_WEBHOOKINGRESSCONTEXT']._serialized_start=3636
  _globals['_WEBHOOKINGRESSCONTEXT']._serialized_end=3939
  _globals['_WEBHOOKINGRESSCONTEXT_HEADERSENTRY']._serialized_start=3893
  _globals['_WEBHOOKINGRESSCONTEXT_HEADERSENTRY']._serialized_end=3939
  _globals['_GOALOPERATIONREQUEST']._serialized_start=3942
  _globals['_GOALOPERATIONREQUEST']._serialized_end=4267
  _globals['_GOALOPERATIONRESPONSE']._serialized_start=4270
  _globals['_GOALOPERATIONRESPONSE']._serialized_end=4645
  _globals['_GOALOPERATIONRESPONSE_AGGREGATESBYGOALENTRY']._serialized_start=4551
  _globals['_GOALOPERATIONRESPONSE_AGGREGATESBYGOALENTRY']._serialized_end=4645
  _globals['_GOALSUBLEDGEREVENT']._serialized_start=4648
  _globals['_GOALSUBLEDGEREVENT']._serialized_end=4859
  _globals['_INSIGHTTRIGGERCONTEXT']._serialized_start=4862
  _globals['_INSIGHTTRIGGERCONTEXT']._serialized_end=5165
  _globals['_INSIGHTTRIGGERCONTEXT_HINTSENTRY']._serialized_start=5121
  _globals['_INSIGHTTRIGGERCONTEXT_HINTSENTRY']._serialized_end=5165
  _globals['_DATAREADYCONTEXT']._serialized_start=5168
  _globals['_DATAREADYCONTEXT']._serialized_end=5394
  _globals['_CATEGORYDETERMINATIONREQUESTCONTEXT']._serialized_start=5396
  _globals['_CATEGORYDETERMINATIONREQUESTCONTEXT']._serialized_end=5472
  _globals['_CATEGORYDETERMINATIONRESPONSECONTEXT']._serialized_start=5475
  _globals['_CATEGORYDETERMINATIONRESPONSECONTEXT']._serialized_end=5664
  _globals['_POSTINGRULEDETERMINATIONREQUESTCONTEXT']._serialized_start=5667
  _globals['_POSTINGRULEDETERMINATIONREQUESTCONTEXT']._serialized_end=5816
  _globals['_POSTINGRULEDETERMINATIONRESPONSECONTEXT']._serialized_start=5819
  _globals['_POSTINGRULEDETERMINATIONRESPONSECONTEXT']._serialized_end=6011
  _globals['_INSIGHTANALYSISREQUESTCONTEXT']._serialized_start=6014
  _globals['_INSIGHTANALYSISREQUESTCONTEXT']._serialized_end=6221
  _globals['_INSIGHTANALYSISRESPONSECONTEXT']._serialized_start=6224
  _globals['_INSIGHTANALYSISRESPONSECONTEXT']._serialized_end=6419
  _globals['_TAXONOMYRELEASECONTEXT']._serialized_start=6422
  _globals['_TAXONOMYRELEASECONTEXT']._serialized_end=6681
  _globals['_POSTINGRULESRELEASECONTEXT']._serialized_start=6684
  _globals['_POSTINGRULESRELEASECONTEXT']._serialized_end=6907
  _globals['_COAUPDATECONTEXT']._serialized_start=6910
  _globals['_COAUPDATECONTEXT']._serialized_end=7123
  _globals['_GENERICEVENTCONTEXT']._serialized_start=7126
  _globals['_GENERICEVENTCONTEXT']._serialized_end=7427
  _globals['_GENERICEVENTCONTEXT_ATTRIBUTESENTRY']._serialized_start=7378
  _globals['_GENERICEVENTCONTEXT_ATTRIBUTESENTRY']._serialized_end=7427
  _globals['_GOALEVENTCONTEXT']._serialized_start=7430
  _globals['_GOALEVENTCONTEXT']._serialized_end=7651
  _globals['_SUGGESTIONEVENT']._serialized_start=7654
  _globals['_SUGGESTIONEVENT']._serialized_end=7974
  _globals['_DATAAVAILABLECONTEXT']._serialized_start=7977
  _globals['_DATAAVAILABLECONTEXT']._serialized_end=8241
  _globals['_ETLFAILEDCONTEXT']._serialized_start=8244
  _globals['_ETLFAILEDCONTEXT']._serialized_end=8445
  _globals['_POSTINGFAILEDCONTEXT']._serialized_start=8448
  _globals['_POSTINGFAILEDCONTEXT']._serialized_end=8632
  _globals['_FXRATEREQUESTCONTEXT']._serialized_start=8635
  _globals['_FXRATEREQUESTCONTEXT']._serialized_end=8939
  _globals['_FXRATERESPONSECONTEXT']._serialized_start=8942
  _globals['_FXRATERESPONSECONTEXT']._serialized_end=9151
  _globals['_CONNECTIONRECONCILEDCONTEXT']._serialized_start=9154
  _globals['_CONNECTIONRECONCILEDCONTEXT']._serialized_end=9408
  _globals['_DUPLICATEACCOUNTPAIR']._serialized_start=9410
  _globals['_DUPLICATEACCOUNTPAIR']._serialized_end=9486
  _globals['_IDENTITYCONTEXT']._serialized_start=9489
  _globals['_IDENTITYCONTEXT']._serialized_end=9779
  _globals['_MESSAGEHEADER']._serialized_start=9782
  _globals['_MESSAGEHEADER']._serialized_end=10129
  _globals['_PROCESSINGSUMMARY']._serialized_start=10132
  _globals['_PROCESSINGSUMMARY']._serialized_end=10358
  _globals['_DATAQUALITYMETRICS']._serialized_start=10361
  _globals['_DATAQUALITYMETRICS']._serialized_end=10790
  _globals['_DATAQUALITYMETRICS_FIELDCOMPLETENESSENTRY']._serialized_start=10676
  _globals['_DATAQUALITYMETRICS_FIELDCOMPLETENESSENTRY']._serialized_end=10732
  _globals['_DATAQUALITYMETRICS_VALIDATIONRESULTSENTRY']._serialized_start=10734
  _globals['_DATAQUALITYMETRICS_VALIDATIONRESULTSENTRY']._serialized_end=10790
  _globals['_POSTINGSUMMARY']._serialized_start=10793
  _globals['_POSTINGSUMMARY']._serialized_end=11075
  _globals['_DATADETAILS']._serialized_start=11077
  _globals['_DATADETAILS']._serialized_end=11128
  _globals['_POSTINGLEG']._serialized_start=11131
  _globals['_POSTINGLEG']._serialized_end=11278
  _globals['_GOALEVENTPAYLOAD']._serialized_start=11281
  _globals['_GOALEVENTPAYLOAD']._serialized_end=11721
  _globals['_ALLOCATIONSETTINGS']._serialized_start=11724
  _globals['_ALLOCATIONSETTINGS']._serialized_end=12027
  _globals['_ALLOCATIONCONTEXT']._serialized_start=12030
  _globals['_ALLOCATIONCONTEXT']._serialized_end=12287
  _globals['_EARMARKREQUEST']._serialized_start=12290
  _globals['_EARMARKREQUEST']._serialized_end=12501
  _globals['_EARMARKREQUEST_SOURCEMETADATAENTRY']._serialized_start=12448
  _globals['_EARMARKREQUEST_SOURCEMETADATAENTRY']._serialized_end=12501
  _globals['_SPENDREQUEST']._serialized_start=12503
  _globals['_SPENDREQUEST']._serialized_end=12611
  _globals['_ALLOCATEREQUEST']._serialized_start=12614
  _globals['_ALLOCATEREQUEST']._serialized_end=12751
  _globals['_ALLOCATION']._serialized_start=12753
  _globals['_ALLOCATION']._serialized_end=12812
  _globals['_REFUNDREQUEST']._serialized_start=12815
  _globals['_REFUNDREQUEST']._serialized_end=12951
  _globals['_SUBLEDGERENTRY']._serialized_start=12954
  _globals['_SUBLEDGERENTRY']._serialized_end=13239
  _globals['_GOALAGGREGATES']._serialized_start=13242
  _globals['_GOALAGGREGATES']._serialized_end=13463
  _globals['_SUGGESTIONCANDIDATE']._serialized_start=13465
  _globals['_SUGGESTIONCANDIDATE']._serialized_end=13576
  _globals['_FXRATEENTRY']._serialized_start=13579
  _globals['_FXRATEENTRY']._serialized_end=13731
# @@protoc_insertion_point(module_scope)
